@@ -4,7 +4,7 @@
 #include "gsd-device-manager.h"
 #include "gsd-common-enums.h"
 
-/* enumerations from "/usr/src/ports/gnome-control-center/gnome-control-center-3.22.2-1.x86_64/src/gnome-control-center-3.22.2/panels/common/gsd-device-manager.h" */
+/* enumerations from "/usr/src/ports/gnome-control-center/gnome-control-center-3.24.3-1.i686/src/gnome-control-center-3.24.3/panels/common/gsd-device-manager.h" */
 GType
 gsd_device_type_get_type (void)
 {
@@ -16,6 +16,7 @@ gsd_device_type_get_type (void)
       { GSD_DEVICE_TYPE_TOUCHPAD, "GSD_DEVICE_TYPE_TOUCHPAD", "touchpad" },
       { GSD_DEVICE_TYPE_TABLET, "GSD_DEVICE_TYPE_TABLET", "tablet" },
       { GSD_DEVICE_TYPE_TOUCHSCREEN, "GSD_DEVICE_TYPE_TOUCHSCREEN", "touchscreen" },
+      { GSD_DEVICE_TYPE_PAD, "GSD_DEVICE_TYPE_PAD", "pad" },
       { 0, NULL, NULL }
     };
     etype = g_flags_register_static ("GsdDeviceType", values);
